diff --git a/components/bower.json b/components/bower.json
index cb17eb32d..0f54800af 100644
--- a/components/bower.json
+++ b/components/bower.json
@@ -1,6 +1,6 @@
 {
   "name": "handlebars",
-  "version": "4.0.1",
+  "version": "4.0.2",
   "main": "handlebars.js",
   "license": "MIT",
   "dependencies": {}
diff --git a/components/handlebars.js.nuspec b/components/handlebars.js.nuspec
index ee1fce077..ebdb8932c 100644
--- a/components/handlebars.js.nuspec
+++ b/components/handlebars.js.nuspec
@@ -2,7 +2,7 @@
 <package>
 	<metadata>
 		<id>handlebars.js</id>
-		<version>4.0.1</version>
+		<version>4.0.2</version>
 		<authors>handlebars.js Authors</authors>
 		<licenseUrl>https://github.com/wycats/handlebars.js/blob/master/LICENSE</licenseUrl>
 		<projectUrl>https://github.com/wycats/handlebars.js/</projectUrl>
diff --git a/lib/handlebars/base.js b/lib/handlebars/base.js
index 087874a5d..53469eb2d 100644
--- a/lib/handlebars/base.js
+++ b/lib/handlebars/base.js
@@ -4,7 +4,7 @@ import {registerDefaultHelpers} from './helpers';
 import {registerDefaultDecorators} from './decorators';
 import logger from './logger';
 
-export const VERSION = '4.0.1';
+export const VERSION = '4.0.2';
 export const COMPILER_REVISION = 7;
 
 export const REVISION_CHANGES = {
diff --git a/lib/handlebars/runtime.js b/lib/handlebars/runtime.js
index 6b31a7ba4..52d9b9483 100644
--- a/lib/handlebars/runtime.js
+++ b/lib/handlebars/runtime.js
@@ -161,7 +161,7 @@ export function template(templateSpec, env) {
       if (templateSpec.usePartial) {
         container.partials = container.merge(options.partials, env.partials);
       }
-      if (templateSpec.useDecorators) {
+      if (templateSpec.usePartial || templateSpec.useDecorators) {
         container.decorators = container.merge(options.decorators, env.decorators);
       }
     } else {
diff --git a/package.json b/package.json
index 8752ea0e7..970d13e4c 100644
--- a/package.json
+++ b/package.json
@@ -1,7 +1,7 @@
 {
   "name": "handlebars",
   "barename": "handlebars",
-  "version": "4.0.1",
+  "version": "4.0.2",
   "description": "Handlebars provides the power necessary to let you build semantic templates effectively with no frustration",
   "homepage": "http://www.handlebarsjs.com/",
   "keywords": [
diff --git a/release-notes.md b/release-notes.md
index ef55b63e8..822cb80fa 100644
--- a/release-notes.md
+++ b/release-notes.md
@@ -2,7 +2,12 @@
 
 ## Development
 
-[Commits](https://github.com/wycats/handlebars.js/compare/v4.0.1...master)
+[Commits](https://github.com/wycats/handlebars.js/compare/v4.0.2...master)
+
+## v4.0.2 - September 4th, 2015
+- [#1089](https://github.com/wycats/handlebars.js/issues/1089) - "Failover content" not working in multiple levels of inline partials ([@michaellopez](https://api.github.com/users/michaellopez))
+
+[Commits](https://github.com/wycats/handlebars.js/compare/v4.0.1...v4.0.2)
 
 ## v4.0.1 - September 2nd, 2015
 - Fix failure when using decorators in partials - 05b82a2
diff --git a/spec/regressions.js b/spec/regressions.js
index ae0797e9a..cca126e37 100644
--- a/spec/regressions.js
+++ b/spec/regressions.js
@@ -212,4 +212,12 @@ describe('Regressions', function() {
     };
     shouldCompileToWithPartials(string, [{}, {}, partials], true, 'doctypelayoutsubcontent');
   });
+  it('GH-1089: should support failover content in multiple levels of inline partials', function() {
+    var string = '{{#> layout}}{{/layout}}';
+    var partials = {
+      doctype: 'doctype{{> content}}',
+      layout: '{{#> doctype}}{{#*inline "content"}}layout{{#> subcontent}}subcontent{{/subcontent}}{{/inline}}{{/doctype}}'
+    };
+    shouldCompileToWithPartials(string, [{}, {}, partials], true, 'doctypelayoutsubcontent');
+  });
 });
